InMemoryChannelRegistry class
- Implemented types
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
occupiedChannels
→ Iterable<
ChannelInfo> -
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
disconnect(
SocketConnection connection) → Future< void> -
override
-
info(
String channel) → ChannelInfo? -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
publish(
String channel, String event, Object? data, {String? exceptSocketId}) → Future< void> -
override
-
subscribe(
SocketConnection connection, String channel, {Map< String, Object?> ? member}) → Future<void> -
override
-
toString(
) → String -
A string representation of this object.
inherited
-
unsubscribe(
SocketConnection connection, String channel) → Future< void> -
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited